@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::GitHub::Create;
 BEGIN {
-  $Dist::Zilla::Plugin::GitHub::Create::VERSION = '0.01';
+  $Dist::Zilla::Plugin::GitHub::Create::VERSION = '0.02';
 }
 
 use Moose;
@@ -34,7 +34,7 @@ Dist::Zilla::Plugin::GitHub::Create - Create GitHub repo on dzil new
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -47,7 +47,7 @@ In your F<profile.ini>:
 
 =head1 DESCRIPTION
 
-This Dist::Zilla Plugin creates a new git repository on GitHub.com when
+This Dist::Zilla plugin creates a new git repository on GitHub.com when
 a new distribution is created with C<dzil new>.
 
 =cut
@@ -130,44 +130,6 @@ Create a public repository if this is '1' (default), else create a private one.
 
 Alessandro Ghedini <alexbio@cpan.org>
 
-=head1 BUGS
-
-Please report any bugs or feature requests at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dist-Zilla-Plugin-GitHub>.
-I will be notified, and then you'll automatically be notified of progress
-on your bug as I make changes.
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Dist::Zilla::Plugin::GitHub::Create
-
-You can also look for information at:
-
-=over 4
-
-=item * GitHub page
-
-L<http://github.com/AlexBio/Dist-Zilla-Plugin-GitHub>
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Dist-Zilla-Plugin-GitHub>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Dist-Zilla-Plugin-GitHub>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Dist-Zilla-Plugin-GitHub>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Dist-Zilla-Plugin-GitHub/>
-
-=back
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2011 Alessandro Ghedini.
